//  Copyright (C) 2011, 2014 Ben Asselstine
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 3 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU Library General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 
//  02110-1301, USA.

#include "cbc-show.h"
CBCShow::CBCShow(Glib::ustring id, Glib::ustring title, Glib::ustring desc,
                 bool live)
  :d_id(id), d_title(title), d_desc(desc), d_live(live)
{
}

CBCShow::CBCShow(const CBCShow& t)
  :d_id(t.d_id), d_title(t.d_title), d_desc(t.d_desc), d_live(t.d_live)
{
}

CBCShow::~CBCShow()
{
}
